
<p align="center">
  <a href="https://github.com/memory-formation/psychos">
    <picture>
        <source media="(prefers-color-scheme: dark)" srcset="https://github.com/memory-formation/psychos/raw/main/docs/assets/psychos-dark.svg">
        <img alt="dmf-utils" src="https://github.com/memory-formation/psychos/raw/main/docs/assets/psychos.svg">
    </picture>
  </a>
</p>